@@ -12,15 +12,16 @@ from .constants import (
     SCRIBE_VULNERABILITIES_DATASET,
     SCRIBE_PRODUCTS_DATASET,
     SCRIBE_POLICY_DATASET,
-    SCRIBE_TEAM_STAT_DATASET
+    SCRIBE_TEAM_STAT_DATASET,
+    SCRIBE_LINEAGE_DATASET
 )
 
 class ScribeClient:
-    scribe_vulnerabilities_dataset = "API Vulnerabilities"
-    scribe_products_dataset = "asbom_filtered"
-    scribe_policy_dataset = "Policy results v5"
-    scribe_team_stat_dataset ="MARKETING Team activity"
-    scribe_lineage_dataset="extended_lineage_new"
+    scribe_vulnerabilities_dataset = SCRIBE_VULNERABILITIES_DATASET
+    scribe_products_dataset = SCRIBE_PRODUCTS_DATASET
+    scribe_policy_dataset = SCRIBE_POLICY_DATASET
+    scribe_team_stat_dataset = SCRIBE_TEAM_STAT_DATASET
+    scribe_lineage_dataset=SCRIBE_LINEAGE_DATASET
 
     def get_chache_data(self):
         return {
@@ -769,18 +770,21 @@ class ScribeClient:
                         "columns": [
                             "logical_app",
                             "logical_app_version",
+                            "asset_type",
+                            "asset_name",
                             "status",
                             "time_evaluated",
-                            "initiative_id",
-                            "gen_rule_name",
-                            "status_string",
+                            "initiative_name",
+                            "control_name",
+                            "rule_name",
+                            "message"
                         ],
                         "filters": [
-                            {
-                                "col": "initiative_id",
-                                "op": "like",
-                                "val": initiative
-                            },
+                            # {
+                            #     "col": "initiative_name",
+                            #     "op": "like",
+                            #     "val": initiative
+                            # },
                             {
                                 "col": "logical_app",
                                 "op": "==",
@@ -793,12 +797,12 @@ class ScribeClient:
                             },
                             {
                                 "col": "status",
-                                "op": "!=",
-                                "val": 'notApplicable'
+                                "op": "not in",
+                                "val": ['Not Applicable', 'Not Applicable']
                             }
                         ],
                         "metrics": [],
-                        "orderby": [["time_evaluated", False], ["status", True]],
+                        "orderby": [],#["time_evaluated", False], ["status", True]],
                         "row_limit": 10
                     }
                 ],
@@ -818,44 +822,19 @@ class ScribeClient:
                 return {}, logical_app_version
         return {}, logical_app_version
 
-    def get_policy_results_str(self, logical_app="scribe-platform", logical_app_version=None, initiative="%", with_link=True):
+    def get_policy_results_str(self, logical_app="scribe-platform", logical_app_version=None, initiative="%", with_link = True):
         r, logical_app_version = self.get_policy_results(logical_app, logical_app_version, initiative)
         if not r:
             return "Failed getting policy results"
 
+        o = f"Policy results for {logical_app}:\n"
         try:
-            policy_list = r["result"][0]["data"]
-            if not policy_list:
-                return f"No policy results found for product {logical_app}: {logical_app_version} and initiative {initiative}"
-
-            # Prepare headers and rows for the table
-            headers = ["Rule", "Status", "Time Evaluated", "Type", "Details"]
-            rows = [
-                [
-                    result['gen_rule_name'],
-                    result['status'],
-                    result['time_evaluated'],
-                    result['initiative_id'],
-                    result['status_string'].replace('\n', ' ')
-                ]
-                for result in policy_list
-            ]
-
-            # Format the table
-            table = self.format_table(headers, rows)
-
-            if with_link:
-                table += self.get_link(
-                    use="product_policy_results",
-                    text="Policy results",
-                    params={"product": logical_app, "product_version": logical_app_version, "show_file_components": "false"}
-                )
+            o = self.query_result_to_str(o, r)
 
         except Exception as e:
             logging.error(f"Error decoding JSON: {e}")
-            table = "Error getting policy results"
-
-        return table
+            o = "Error getting policy results"
+        return o
     
      
     def get_product_lineage(self, logical_app, logical_app_version=None):
